==> haskell-uuid-1.3.13-3-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-uuid.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: uuid
version: 1.3.13
id: uuid-1.3.13-Dtwa7uQPao7BTXtMhkKopa
key: uuid-1.3.13-Dtwa7uQPao7BTXtMhkKopa
license: BSD3
copyright: (c) 2008-2014 Antoine Latter
maintainer: hvr@gnu.org
homepage: https://github.com/hvr/uuid
synopsis: For creating, comparing, parsing and printing Universally Unique Identifiers
description:
    This library is useful for creating, comparing, parsing and
    printing Universally Unique Identifiers.
    .
    See <http://en.wikipedia.org/wiki/UUID> for the general idea.
category: Data
author: Antoine Latter
exposed: True
exposed-modules:
    Data.UUID Data.UUID.Util Data.UUID.V1 Data.UUID.V3 Data.UUID.V4
    Data.UUID.V5
hidden-modules: Data.UUID.Named Data.Word.Util
abi: 7dd238c0b28235b3cdbe2600f7ceb00c
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/uuid-1.3.13
library-dirs: /usr/lib/ghc-8.0.1/site-local/uuid-1.3.13
data-dir: /usr/share/x86_64-linux-ghc-8.0.1/uuid-1.3.13
hs-libraries: HSuuid-1.3.13-Dtwa7uQPao7BTXtMhkKopa
depends:
    base-4.9.0.0 binary-0.8.3.0 bytestring-0.10.8.1
    cryptohash-md5-0.11.100.1-9Crf9wW9dLGV2WJt31xcX
    cryptohash-sha1-0.11.100.1-CglqrWLTxPN69LKXoyo6
    entropy-0.3.7-54dsRvsNlllHvcIX99CGiD
    network-info-0.2.0.8-86rzpOQvMAKDGx0U3gGJUk
    random-1.1-54KmMHXjttlERYcr1mvsAe
    text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ time-1.6.0.1
    uuid-types-1.0.3-9AR9NqIFJzo61iW1wAnWIZ
haddock-interfaces: /usr/share/doc/haskell-uuid/html/uuid.haddock
haddock-html: /usr/share/doc/haskell-uuid/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-uuid-1.3.13-4-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-uuid.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: uuid
version: 1.3.13
id: uuid-1.3.13-8vjc2g7cR8ZGE13W8Lbdq3
key: uuid-1.3.13-8vjc2g7cR8ZGE13W8Lbdq3
license: BSD3
copyright: (c) 2008-2014 Antoine Latter
maintainer: hvr@gnu.org
homepage: https://github.com/hvr/uuid
synopsis: For creating, comparing, parsing and printing Universally Unique Identifiers
description:
    This library is useful for creating, comparing, parsing and
    printing Universally Unique Identifiers.
    .
    See <http://en.wikipedia.org/wiki/UUID> for the general idea.
category: Data
author: Antoine Latter
exposed: True
exposed-modules:
    Data.UUID Data.UUID.Util Data.UUID.V1 Data.UUID.V3 Data.UUID.V4
    Data.UUID.V5
hidden-modules: Data.UUID.Named Data.Word.Util
abi: e2fab93f9b93a322d466af2bf0d4ef50
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/uuid-1.3.13
library-dirs: /usr/lib/ghc-8.0.1/site-local/uuid-1.3.13
data-dir: /usr/share/x86_64-linux-ghc-8.0.1/uuid-1.3.13
hs-libraries: HSuuid-1.3.13-8vjc2g7cR8ZGE13W8Lbdq3
depends:
    base-4.9.0.0 binary-0.8.3.0 bytestring-0.10.8.1
    cryptohash-md5-0.11.100.1-9Crf9wW9dLGV2WJt31xcX
    cryptohash-sha1-0.11.100.1-CglqrWLTxPN69LKXoyo6
    entropy-0.3.7-54dsRvsNlllHvcIX99CGiD
    network-info-0.2.0.8-86rzpOQvMAKDGx0U3gGJUk
    random-1.1-54KmMHXjttlERYcr1mvsAe
    text-1.2.2.2-9rr3K4o0GAG9P33dGDnV9v time-1.6.0.1
    uuid-types-1.0.3-Ehz3Hb8wPTNLGYb3sWO6HS
haddock-interfaces: /usr/share/doc/haskell-uuid/html/uuid.haddock
haddock-html: /usr/share/doc/haskell-uuid/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
